@@ -399,6 +399,7 @@ class Client:
                 self.print_progress_bar(
                     progress=new_progress,
                     bytes_=bytes_sent,
+                    force=(new_progress == 100)
                 )
         print()  # New line after progress_bar
         writer.close()
@@ -431,7 +432,8 @@ class Client:
                 )
                 self.print_progress_bar(
                     progress=new_progress,
-                    bytes_=bytes_received
+                    bytes_=bytes_received,
+                    force=(new_progress == 100)
                 )
                 if not input_data:
                     break
